Crate rsdiff_macros

Crate rsdiff_macros 

rsdiff-macros

Macros

autodiff
Compute the partial derivative of a given expression w.r.t a particular variable. At the moment, the macro only supports expressions defined within the same scope.